**Dimensigon (DM)** is our backend technology at store.dimensigon.com to bootstrap ELASTIC Services.

As main features:

- Polyglot or Heterogeneous orquestrations
- Mesh Networking
- Decentralization of IoT or IoT 2.0 as we understand it for our own implementation.
- Distributed-Decentralized Server Management, High-complex orchestrations
- Full RESTful and easily embeddable
- Distributed Vault for Configuration Management or Secrets
- Log Federation
- Double Encryption (SSL + Encrypted messaging by default)
- ACLs for higher granularity and security control on top of OS Security.


All these functionality makes **Dimensigon (DM)** a good standard for companies serving as Coordination layer for all automation technologies (Polyglot).
**Dimensigon** (DM) lowers the costs of administration and simplify the management of high-complex environments like Hybrid Multi-Cloud.
 

**Dimensigon (DM)** is a 100% Python and REAL Open Source project.

**REAL Open Source** => No Freemium or Enterprise versions would be available in the future

